/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Input } from '@angular/core';
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class Messages extends ComponentMessages {
    /**
     * Specifies the text for the SplitButton `aria-label`.
     *
     * The `aria-label` text consists of two parts: the SplitButton text and a localizable string.
     * For example, for a SplitButton with the text `'Reply'`, the default `aria-label` is `'Reply splitbutton'`.
     *
     * To reorder the SplitButton text and the localizable part, use the `splitButtonLabel` property with a
     * placeholder for the button text, such as `'splitbutton for {buttonText}'`. The `{buttonText}` placeholder
     * is replaced internally with the current SplitButton text. For instance, the resulting `aria-label` is
     * rendered as `'splitbutton for Reply'`.
     *
     * @example
     * ```ts
     * <kendo-splitbutton>
     *     <kendo-splitbutton-messages
     *         splitButtonLabel="splitbutton for {buttonText}">
     *     </kendo-splitbutton-messages>
     * </kendo-splitbutton>
     * ```
     */
    splitButtonLabel;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: Messages, selector: "kendo-splitbutton-messages-base", inputs: { splitButtonLabel: "splitButtonLabel" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'kendo-splitbutton-messages-base'
                }]
        }], propDecorators: { splitButtonLabel: [{
                type: Input
            }] } });
