/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ViewContainerRef } from '@angular/core';
/**
 * Configures the popup settings.
 *
 * @example
 * ```ts
 * @Component({
 * selector: 'my-app',
 * template: `
 * <kendo-splitbutton [data]="items" [popupSettings]="popupSettings">
 *    SplitButton
 * </kendo-splitbutton>
 * `
 * })
 * class AppComponent {
 *   public popupSettings: PopupSettings = {
 *      popupClass: 'customClass',
 *      align: 'center',
 *   };
 *   public items: Array<any> = [{
 *      text: 'item1'
 *   }, {
 *      text: 'item2'
 *   }];
 * }
 * ```
 */
export interface PopupSettings {
    /**
     * Enables or disables the popup animation.
     * By default, the open and close animations are enabled.
     */
    animate?: boolean;
    /**
     * Specifies CSS classes for styling the popup.
     */
    popupClass?: string;
    /**
     * Specifies the container for the popup.
     * By default, the popup is appended to the root component.
     */
    appendTo?: 'root' | 'component' | ViewContainerRef;
    /**
     * Specifies the alignment of the popup.
     * By default, the popup is left-aligned.
     */
    align?: 'left' | 'center' | 'right';
}
