/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class Messages extends ComponentMessages {
    /**
     * Specifies the text for the SplitButton `aria-label`.
     *
     * The `aria-label` text consists of two parts: the SplitButton text and a localizable string.
     * For example, for a SplitButton with the text `'Reply'`, the default `aria-label` is `'Reply splitbutton'`.
     *
     * To reorder the SplitButton text and the localizable part, use the `splitButtonLabel` property with a
     * placeholder for the button text, such as `'splitbutton for {buttonText}'`. The `{buttonText}` placeholder
     * is replaced internally with the current SplitButton text. For instance, the resulting `aria-label` is
     * rendered as `'splitbutton for Reply'`.
     *
     * @example
     * ```ts
     * <kendo-splitbutton>
     *     <kendo-splitbutton-messages
     *         splitButtonLabel="splitbutton for {buttonText}">
     *     </kendo-splitbutton-messages>
     * </kendo-splitbutton>
     * ```
     */
    splitButtonLabel: string;
    static ɵfac: i0.ɵɵFactoryDeclaration<Messages, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<Messages, "kendo-splitbutton-messages-base", never, { "splitButtonLabel": { "alias": "splitButtonLabel"; "required": false; }; }, {}, never, never, false, never>;
}
